==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/docking/translations/docking_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation>Sobre parpadeante</translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation>Sobre estático</translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation>Sobre animado</translation>
    </message>
    <message>
        <source>Startup</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Show tooltip over tray icon</source>
        <translation>Mostrar sugerencia sobre el icono de bandeja</translation>
    </message>
    <message>
        <source>Tray icon indicating new message</source>
        <translation>Icono de bandeja indicando un nuevo mensaje</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Salir de Kadu</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Estados</translation>
    </message>
    <message>
        <source>Descriptions</source>
        <translation>Descripciones</translation>
    </message>
    <message>
        <source>Silent mode</source>
        <translation>Modo silencioso</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/docking/translations/docking_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation>Sobre parpadeante</translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation>Sobre estático</translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation>Sobre animado</translation>
    </message>
    <message>
        <source>Startup</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Show tooltip over tray icon</source>
        <translation>Mostrar sugerencia sobre el icono de bandeja</translation>
    </message>
    <message>
        <source>Tray icon indicating new message</source>
        <translation>Icono de bandeja indicando un nuevo mensaje</translation>
    </message>
</context>
<context>
    <name>DockingMenuHandler</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>Silent mode</source>
        <translation>Modo silencioso</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Salir de Kadu</translation>
    </message>
</context>
</TS>
